import evaluate


def evaluate_rouge(model, val_dataloader, processor):
    glue = evaluate.load("rouge")

    for batch in val_dataloader:
        completion = model.generate(
            input_ids=batch["input_ids"],
            attention_mask=batch["attention_mask"],
            pixel_values=batch["pixel_values"],
            image_grid_thw=batch["image_grid_thw"],
            max_length=1000,
        )
        target = batch["answers_ids"]
        generated_text = [
            out_ids[len(in_ids) :]
            for out_ids, in_ids in zip(completion, batch["input_ids"])
        ]
        generated_text = processor.tokenizer.batch_decode(
            generated_text, skip_special_tokens=True
        )
        target_text = processor.tokenizer.batch_decode(target, skip_special_tokens=True)
        glue.add_batch(predictions=generated_text, references=target_text)

    print(glue.compute())